/*
 * Copyright (c) 2017, 2020 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.positiveinteger.totaldigits.totaldigits_3;

import jakarta.xml.bind.*;
import jakarta.xml.bind.TypeConstraintException;
import java.math.BigInteger;
import javasoft.sqe.javatest.Status;
import java.io.PrintWriter;
import javasoft.sqe.tests.api.jakarta.xml.bind.CTTest;

public class totalDigits3_ValidateCTTests extends CTTest {

    /**
     * Command line starter.
     */
    public static void main(String[] args) {
        totalDigits3_ValidateCTTests test = new totalDigits3_ValidateCTTests();
        PrintWriter err = new PrintWriter(System.err, true);
        PrintWriter out = new PrintWriter(System.out, true);
        Status status = test.run(args, err, out);
        err.flush();
        out.flush();
        status.exit();
    }

    final BigInteger[] validValues = {new BigInteger("999999999"), new BigInteger("100000000"),
                                      new BigInteger("10000000"), new BigInteger("1000000"),
                                      new BigInteger("100000"), new BigInteger("10000"),
                                      new BigInteger("1000"), new BigInteger("100"),
                                      new BigInteger("10"), new BigInteger("1")};
    final BigInteger[] invalidValues = {new BigInteger("1000000000"), new BigInteger("0"), 
                                        new BigInteger("-100000000"), new BigInteger("-999999999")};
    
    JAXBElement<BigInteger> elemObj;

    Status testInvalid() {
        for (int i = 0; i < invalidValues.length; ++i){
            
                elemObj.setValue(invalidValues[i]);
                Status status = validate(elemObj);
                if (status.isPassed()) {
                    return Status.failed("" + invalidValues[i] + " is unexpectedly valid");
                }
            
        }
        return Status.passed("OK");
    }

    Status testValid() {
        for (int i = 0; i < validValues.length; ++i){
            elemObj.setValue(validValues[i]);
            Status status = validate(elemObj);
            if (!status.isPassed()){
                return Status.failed("" + validValues[i] + " is unexpectedly invalid");
            }
        }
        return Status.passed("OKAY");
    }

    public Status Validate001( ) {
        String xmlDocName = "totalDigits-3-1.xml";
        elemObj = (JAXBElement<BigInteger>)unmarshal(xmlDocName);
        return testValid();
    }

    public Status Validate002( ) {
        String xmlDocName = "totalDigits-3-1.xml";
        elemObj = (JAXBElement<BigInteger>)unmarshal(xmlDocName);
        return testInvalid();
    }

    public Status Validate003( ) {
        elemObj = (JAXBElement<BigInteger>)(new ObjectFactory()).createNISTSchemaPositiveIntegerTotalDigits3(new BigInteger("6"));
        
        return testValid();
    }

    public Status Validate004( ) {
        elemObj = (JAXBElement<BigInteger>)(new ObjectFactory()).createNISTSchemaPositiveIntegerTotalDigits3(new BigInteger("6"));
        
        return testInvalid();
    }


}

